@@ -31,11 +31,11 @@ Struct::Diff - Recursive diff tools for nested perl structures
 
 =head1 VERSION
 
-Version 0.83
+Version 0.84
 
 =cut
 
-our $VERSION = '0.83';
+our $VERSION = '0.84';
 
 =head1 SYNOPSIS
 
@@ -76,7 +76,7 @@ Means 'different' and contains subdiff.
 
 =item I
 
-Shows index for changed array item.
+Index for changed array item.
 
 =item N
 
@@ -104,7 +104,7 @@ Returns hashref to recursive diff between two passed things. Beware when
 changing diff: some of it's substructures are links to original structures.
 
     $diff = diff($a, $b, %opts);
-    $patch = diff($a, $b, noU => 1, noO => 1, trimR => '1'); # smallest possible diff
+    $patch = diff($a, $b, noU => 1, noO => 1, trimR => 1); # smallest possible diff
 
 =head3 Available options
 
@@ -218,8 +218,8 @@ sub diff($$;@) {
 Divide diff to pseudo original structures
 
     $structs = dsplit($diff);
-    # $structs->{'a'} - now contains items originated from $a
-    # $structs->{'b'} - same for $b
+    # $structs->{a} - now contains items originated from $a
+    # $structs->{b} - same for $b
 
 =cut
 
@@ -304,7 +304,7 @@ sub dtraverse($$;$) {
     if (exists $d->{'D'} and (not exists $o->{'depth'} or $o->{'depth'} >= @{$p})) {
         if (ref $d->{'D'} eq 'ARRAY') {
             for (my $i = 0; $i < @{$d->{'D'}}; $i++) {
-                push @{$p}, [$i];
+                push @{$p}, [ exists $d->{'D'}->[$i]->{I} ? $d->{'D'}->[$i]->{I} : $i ];
                 dtraverse($d->{'D'}->[$i], $o, $p) or return undef;
                 pop @{$p};
             }
